@@ -12,7 +12,7 @@ Key Features:
 - Professional package architecture
 """
 
-__version__ = "1.0.0"
+__version__ = "1.1.0"
 __author__ = "Aman Ulla"
 __email__ = "connectamanulla@gmail.com"
 
@@ -37,6 +37,8 @@ from .analyzers.competitive_risk import CompetitiveRiskAnalyzer, CompetitiveRisk
 from .analyzers.legal_risk import LegalRiskAnalyzer, LegalRiskMCPTool
 from .analyzers.exit_risk import ExitRiskAnalyzer, ExitRiskMCPTool
 from .analyzers.peer_benchmark import PeerBenchmarkAnalyzer, PeerBenchmarkMCPTool
+from .analyzers.lv_analysis import LVAnalysisAnalyzer
+from .tools.lv_analysis_tool import LVAnalysisMCPTool
 
 # Import comprehensive scanner
 from .core.comprehensive_scanner import ComprehensiveRiskScanner
@@ -44,6 +46,9 @@ from .tools.serp_news import SerpNewsMCPTool
 from .tools.serp_pdf_search import SerpPdfSearchMCPTool
 from .tools.perplexity_search import PerplexityMCPTool
 from .tools.upload_extractor import UploadExtractor
+from .tools.knowledge_graph import KnowledgeGraphMCPTool
+from .tools.linkedin_analyzer import LinkedInAnalyzerMCPTool
+from .tools.content_moderation import GoogleContentModerationMCPTool
 
 # Conditional imports for Google Cloud tools
 try:
@@ -77,6 +82,7 @@ __all__ = [
     "LegalRiskAnalyzer",
     "ExitRiskAnalyzer",
     "PeerBenchmarkAnalyzer",
+    "LVAnalysisAnalyzer",
     
     # MCP Tools
     "MarketRiskMCPTool",
@@ -89,6 +95,7 @@ __all__ = [
     "LegalRiskMCPTool",
     "ExitRiskMCPTool",
     "PeerBenchmarkMCPTool",
+    "LVAnalysisMCPTool",
     
     # Comprehensive scanner
     "ComprehensiveRiskScanner",
@@ -96,6 +103,9 @@ __all__ = [
     "SerpPdfSearchMCPTool",
     "PerplexityMCPTool",
     "UploadExtractor",
+    "KnowledgeGraphMCPTool",
+    "LinkedInAnalyzerMCPTool",
+    "GoogleContentModerationMCPTool",
 ]
 
 # Add Vertex AI tools to __all__ if available
